==> qsampler_0.5.0.orig.tar.gz: qsampler-0.5.0/src/qsamplerAbout.h <==
// qsamplerAbout.h
//
/****************************************************************************
   Copyright (C) 2004-2017, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qsamplerAbout_h
#define __qsamplerAbout_h

#include "config.h"

#define QSAMPLER_TITLE        PACKAGE_NAME

#define QSAMPLER_SUBTITLE     "A LinuxSampler Qt GUI Interface"
#define QSAMPLER_WEBSITE      "http://qsampler.sourceforge.net"
#define QSAMPLER_COPYRIGHT    "Copyright (C) 2004-2017, rncbc aka Rui Nuno Capela. All rights reserved."
#define QSAMPLER_COPYRIGHT2   "Copyright (C) 2007-2015, Christian Schoenebeck"

#define QSAMPLER_DOMAIN       "linuxsampler.org"

#endif  // __qsamplerAbout_h


// end of qsamplerAbout.h

==> qsampler_0.6.1.orig.tar.gz: qsampler-0.6.1/src/qsamplerAbout.h <==
// qsamplerAbout.h
//
/****************************************************************************
   Copyright (C) 2004-2019, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qsamplerAbout_h
#define __qsamplerAbout_h

#include "config.h"

#define QSAMPLER_TITLE        PACKAGE_NAME

#define QSAMPLER_SUBTITLE     "A LinuxSampler Qt GUI Interface"
#define QSAMPLER_WEBSITE      "https://qsampler.sourceforge.io"
#define QSAMPLER_COPYRIGHT    "Copyright (C) 2004-2019, rncbc aka Rui Nuno Capela. All rights reserved."
#define QSAMPLER_COPYRIGHT2   "Copyright (C) 2007-2015, Christian Schoenebeck"

#define QSAMPLER_DOMAIN       "linuxsampler.org"

#endif  // __qsamplerAbout_h


// end of qsamplerAbout.h
